@@ -5,11 +5,10 @@ Reference: Heng-Tze Cheng et al. "Wide & Deep Learning for Recommender Systems"
 author: massquantity
 
 """
-import time
 from itertools import islice
 import numpy as np
-import tensorflow as tf
-from tensorflow.python.keras.initializers import (
+import tensorflow as tf2
+from tensorflow.keras.initializers import (
     zeros as tf_zeros,
     truncated_normal as tf_truncated_normal
 )
@@ -29,6 +28,8 @@ from ..utils.unique_features import (
     get_predict_indices_and_values,
     get_recommend_indices_and_values
 )
+tf = tf2.compat.v1
+tf.disable_v2_behavior()
 
 
 class WideDeep(Base, TfMixin, EvalMixin):
@@ -79,7 +80,7 @@ class WideDeep(Base, TfMixin, EvalMixin):
         self.default_prediction = data_info.global_mean if (
                 task == "rating") else 0.0
         self.seed = seed
-        self.user_consumed = None
+        self.user_consumed = data_info.user_consumed
         self.sparse = self._decide_sparse_indices(data_info)
         self.dense = self._decide_dense_values(data_info)
         if self.sparse:
@@ -251,7 +252,6 @@ class WideDeep(Base, TfMixin, EvalMixin):
     def fit(self, train_data, verbose=1, shuffle=True,
             eval_data=None, metrics=None, **kwargs):
         self.show_start_time()
-        self.user_consumed = train_data.user_consumed
         if self.lr_decay:
             n_batches = int(len(train_data) / self.batch_size)
             self.lr, global_steps = lr_decay_config(self.lr, n_batches,
